### Blue dither algorithm, real filter

use parent 'OnePassBitmapAlgorithm';

sub new {
    my $class = shift;

    $self = SUPER::OnePassBitmapAlgorithm->new;
    
    bless $self, $class;

    $self->init; ### sets bitmap undef, componentsbag new
}

sub addBitmap { ### sets bitmap
  my ($self, $bitmap) = @_;

  not defined($bitmap) or die "OnePassFilterAlgorithmBlue : bitmap of the blue dither algorithm is empty !";
  
  $self->{bitmap} = $bitmap;
}

sub pass {
  my $self = shift;

  ######### FIXME TODO
  
  ### 1 of el1 means one follower
  my $secondel1 = MatrixBitmapLoaderComponent->new;
  my $firstel1 = BagElement->new->setNext($secondel1);
  $self->addBagElement1($firstel1);
  
  return SUPER::OnePassBitmapAlgorithm->pass->(OnePassSystemBlue->new); 
}

1;

